Class: SixthSense::Model::Mutant
- Inherits:
-
Struct
- Object
- Struct
- SixthSense::Model::Mutant
- Defined in:
- lib/sixth_sense/model.rb
Instance Attribute Summary collapse
-
#diff ⇒ Object
Returns the value of attribute diff.
-
#id ⇒ Object
Returns the value of attribute id.
-
#killing_hint ⇒ Object
Returns the value of attribute killing_hint.
-
#location ⇒ Object
Returns the value of attribute location.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#operator ⇒ Object
Returns the value of attribute operator.
-
#status ⇒ Object
Returns the value of attribute status.
Instance Method Summary collapse
-
#excluded? ⇒ Boolean
Paper basis: Jia/Harman 2011 describes equivalent mutants as a threat; equivalent/skipped mutants are excluded from the mutation-score denominator.
-
#killed? ⇒ Boolean
Paper basis: Jia/Harman 2011 (doi:10.1109/TSE.2010.62) counts killed mutants as behaviorally distinguished by the test suite.
- #to_h ⇒ Object
Instance Attribute Details
#diff ⇒ Object
Returns the value of attribute diff
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def diff @diff end |
#id ⇒ Object
Returns the value of attribute id
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def id @id end |
#killing_hint ⇒ Object
Returns the value of attribute killing_hint
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def killing_hint @killing_hint end |
#location ⇒ Object
Returns the value of attribute location
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def location @location end |
#metadata ⇒ Object
Returns the value of attribute metadata
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def @metadata end |
#operator ⇒ Object
Returns the value of attribute operator
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def operator @operator end |
#status ⇒ Object
Returns the value of attribute status
174 175 176 |
# File 'lib/sixth_sense/model.rb', line 174 def status @status end |
Instance Method Details
#excluded? ⇒ Boolean
Paper basis: Jia/Harman 2011 describes equivalent mutants as a threat; equivalent/skipped mutants are excluded from the mutation-score denominator.
194 195 196 |
# File 'lib/sixth_sense/model.rb', line 194 def excluded? status == :excluded || status == "excluded" || status == :equivalent || status == :skipped || status == "skipped" end |
#killed? ⇒ Boolean
Paper basis: Jia/Harman 2011 (doi:10.1109/TSE.2010.62) counts killed mutants as behaviorally distinguished by the test suite.
186 187 188 189 190 |
# File 'lib/sixth_sense/model.rb', line 186 def killed? return timeout_killed? if status == :timeout || status == "timeout" status == :killed || status == "killed" || status == :timeout end |
#to_h ⇒ Object
198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/sixth_sense/model.rb', line 198 def to_h { id: id, operator: operator, location: location&.to_h, status: status, diff: diff, killing_hint: killing_hint, metadata: || {} } end |